package com.ruoyi.web.work.domain;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.core.domain.BaseData;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.experimental.Accessors;

import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.util.Date;
import java.util.List;

/**
 * @author lsw
 * @date 2024-07-18
 */
@Data
@TableName(value = "tb_follow_record")
@Accessors(chain = true)
public class FollowRecord extends BaseData {
    private static final long serialVersionUID = 1L;

    private Long id;


    @NotNull(message = "推送类型不能为空")
    @Min(value = 0, message = "只能选择复诊提醒或随访提醒")
    @Max(value = 1, message = "只能选择复诊提醒或随访提醒")
    @ApiModelProperty(value = "提醒类型:0=复诊提醒,1=随访提醒")
    private Integer type;

    @ApiModelProperty(value = "患者id")
    private Long patientId;


    @NotBlank(message = "模板名称或提醒标题不能为空")
    @ApiModelProperty(value = "模板名称")
    @Excel(name = "模板名称",sort =1,width=40)
    private String templateName;

    @ApiModelProperty(value = "患者姓名")
    @Excel(name = "患者姓名",sort =2)
    private String patientName;

    @ApiModelProperty(value = "住院号")
    @Excel(name = "住院号",sort =3)
    @TableField(exist = false)
    private String blh;

    @TableField(exist = false)
    @Excel(name = "出院时间",dateFormat = "yyyy-MM-dd",sort =4)
    private Date dischargeTime;

    @TableField(exist = false)
    @Excel(name = "主管医生",sort =5)
    private String physician;


    @NotBlank(message = "回访内容或者提醒内容不能为空")
    @ApiModelProperty(value = "回访内容")
    private String op;

    @ApiModelProperty(value = "状态:0=未回访,1=已回访")
    @Excel(name = "随访状态", readConverterExp = "0=未回访,1=已回访",sort =8)
    private Integer state;

    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "回访时间",dateFormat = "yyyy-MM-dd HH:mm",sort =300,width=30)
    private Date returnTime;

    @ApiModelProperty(value = "删除标识:0=未删除,1=已删除")
    private Integer delFlag;


    @TableField(exist = false)
    private List<Patient> patientList;
}
