package com.ruoyi.web.work.service.impl;

import cn.hutool.http.HttpUtil;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.web.work.api.util.AppUtil;
import com.ruoyi.web.work.domain.FollowRecord;
import com.ruoyi.web.work.domain.User;
import com.ruoyi.web.work.domain.dto.FollowRecordDto;
import com.ruoyi.web.work.domain.dto.RemoveOrRevertDto;
import com.ruoyi.web.work.domain.dto.VisitDto;
import com.ruoyi.web.work.domain.vo.FollowRecordVoList;
import com.ruoyi.web.work.domain.vo.VisitVoList;
import com.ruoyi.web.work.mapper.FollowRecordMapper;
import com.ruoyi.web.work.mapper.UserMapper;
import com.ruoyi.web.work.service.IFollowRecordService;
import com.ruoyi.web.work.service.IUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.env.Environment;
import org.springframework.stereotype.Service;

import java.text.ParseException;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @author lsw
 * @date 2024-07-18
 */
@Service
public class FollowRecordServiceImpl extends ServiceImpl<FollowRecordMapper, FollowRecord> implements IFollowRecordService {
    @Autowired
    private FollowRecordMapper followRecordMapper;

    @Autowired
    IUserService userService;

    @Autowired
    private Environment env;

    @DataScope(deptAlias = "k", userAlias = "k")
    @Override
    public List<FollowRecord> selectList(FollowRecord followRecord) {
        return followRecordMapper.selectList(followRecord);
    }

    @Override
    public AjaxResult detail(Long id) {
        FollowRecord followRecord = getById(id);
        if (followRecord == null || !followRecord.getPatientId().equals(AppUtil.getUser().getPatientId())) {
            return AjaxResult.error("回访不存在或非法操作");
        }
        return AjaxResult.success(followRecord);
    }

    @Override
    public AjaxResult push(FollowRecordDto dto) {
        FollowRecord followRecord = getById(dto.getId());
        if (followRecord == null || !followRecord.getPatientId().equals(AppUtil.getUser().getPatientId())) {
            return AjaxResult.error("回访不存在或非法操作");
        }
        followRecord.setOp(dto.getOp());
        followRecord.setState(1);
        followRecord.setReturnTime(new Date());
        if (!updateById(followRecord)) {
            throw new ServiceException("提交回访记录失败");
        }
        return AjaxResult.success();
    }

    @Override
    public List<VisitVoList> selectVisitList(VisitDto dto) {
        return followRecordMapper.selectVisitList(dto);
    }

    @Override
    public List<FollowRecordVoList> selectAppList(FollowRecord followRecord) {
        return followRecordMapper.selectAppList(followRecord);
    }

    @Override
    public AjaxResult add(FollowRecord followRecord) {
        if (followRecord.getPatientList().size() == 0) {
            return AjaxResult.error("请选择推送的患者");
        }
        List<FollowRecord> followRecordList = new ArrayList<>();
        followRecord.getPatientList().forEach(e -> {
            FollowRecord record = new FollowRecord();
            record.setType(followRecord.getType());
            record.setTemplateName(followRecord.getTemplateName());
            record.setOp(followRecord.getOp());
            record.setPatientId(e.getId());
            record.setPatientName(e.getName());
            followRecordList.add(record);
        });
        if (!saveBatch(followRecordList)) {
            throw new ServiceException("新增回访记录失败");
        }
        followRecordList.forEach(e -> {
            //sendMessage(e);
        });
        return AjaxResult.success();
    }

    @Override
    public AjaxResult read(Long id) {
        FollowRecord followRecord = getById(id);
        if (followRecord == null || !followRecord.getPatientId().equals(AppUtil.getUser().getPatientId())) {
            return AjaxResult.error("复诊提醒不存在或非法操作");
        }
        followRecord.setState(1);
        followRecord.setReturnTime(new Date());
        updateById(followRecord);
        return AjaxResult.success();
    }

    @Override
    public void sendMessage(FollowRecord record) {
        try {
            JSONObject jsonObject = JSONUtil.parseObj(HttpUtil.get("https://api.weixin.qq.com:4430/cgi-bin/token?grant_type=client_credential&appid=" + env.getProperty("wx.appid") + "&secret=" + env.getProperty("wx.appSecret")));
            JSONObject body = new JSONObject();
            body.set("appid", env.getProperty("wx.appid"));
            JSONObject content = new JSONObject();
            User user = userService.selectUserByPatientId(record.getPatientId());
            if (user == null) {
                return;
            }
            body.set("touser", user.getOpenId());
            body.set("page", "pages/user/index?patientId=" + record.getPatientId());
            //复查提醒
            if (record.getType() == 0) {
                body.set("template_id", "S6JARkInVBjID8QMpgZdSHNyxeMDZQq7lur8YrNK0oY");
                content.set("thing1", new JSONObject().set("value", record.getTemplateName()));//复查提醒名称
                content.set("thing3", new JSONObject().set("value", "岑溪人民医院"));//复查机构
                content.set("thing6", new JSONObject().set("value", StringUtils.truncateTo12Chars(record.getOp())));//备注
            }
            //随访提醒
            if (record.getType() == 1) {
                body.set("template_id", "1Jvx8F22na-tG2Q6HFX_3vRtbiv7zZko6NwX8ICIFXc");
                content.set("thing11", new JSONObject().set("value", record.getTemplateName()));//随访名称
                content.set("thing2", new JSONObject().set("value", "岑溪人民医院"));//随访机构
                content.set("phrase3", new JSONObject().set("value", record.getPatientName()));//就诊人
            }
            body.set("data", content);
            String result = HttpUtil.post("https://api.weixin.qq.com:4430/cgi-bin/message/subscribe/send?access_token=" + jsonObject.getStr("access_token"), body.toString());
            System.out.println("body：" + body);
            System.out.println("小程序订阅消息：" + result);
        } catch (Exception e) {
            System.out.println("小程序订阅消息发送失败");
        }
    }

    @Override
    public AjaxResult removeOrRevertByIds(RemoveOrRevertDto dto) {
        List<FollowRecord> list = new ArrayList();
        for (Long id : dto.getIds()) {
            FollowRecord record = new FollowRecord();
            record.setId(id);
            record.setDelFlag(dto.getOp());
            list.add(record);
        }
        if (!updateBatchById(list)) {
            throw new ServiceException("批量操作失败");
        }
        return AjaxResult.success();
    }
}
